'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true,
});
exports.toEqualCaseInsensitive = toEqualCaseInsensitive;

var _predicate = _interopRequireDefault(require('./predicate'));

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : { default: obj };
}

const passMessage = (utils, received, expected) => () => {
  return (
    utils.matcherHint('.not.toEqualCaseInsensitive') +
    '\n\n' +
    'Expected values to not be equal while ignoring case (using ===):\n' +
    `  ${utils.printExpected(expected)}\n` +
    'Received:\n' +
    `  ${utils.printReceived(received)}`
  );
};

const failMessage = (utils, received, expected) => () => {
  return (
    utils.matcherHint('.toEqualCaseInsensitive') +
    '\n\n' +
    'Expected values to be equal while ignoring case (using ===):\n' +
    `  ${utils.printExpected(expected)}\n` +
    'Received:\n' +
    `  ${utils.printReceived(received)}`
  );
};

function toEqualCaseInsensitive(received, expected) {
  const pass = (0, _predicate.default)(received, expected);
  return {
    pass,
    message: pass ? passMessage(this.utils, received, expected) : failMessage(this.utils, received, expected),
    actual: received,
  };
}
