'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true,
});
exports.toSatisfyAll = toSatisfyAll;

var _predicate = _interopRequireDefault(require('./predicate'));

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : { default: obj };
}

const passMessage = (utils, actual, expected) => () =>
  utils.matcherHint('.not.toSatisfyAll') +
  '\n\n' +
  'Expected array to not satisfy predicate for all values:\n' +
  `  ${utils.printExpected(expected)}\n` +
  'Received:\n' +
  `  ${utils.printReceived(actual)}`;

const failMessage = (utils, actual, expected) => () =>
  utils.matcherHint('.toSatisfyAll') +
  '\n\n' +
  'Expected array to satisfy predicate for all values:\n' +
  `  ${utils.printExpected(expected)}\n` +
  'Received:\n' +
  `  ${utils.printReceived(actual)}`;

function toSatisfyAll(actual, expected) {
  const pass = (0, _predicate.default)(actual, expected);

  if (pass) {
    return {
      pass: true,
      message: passMessage(this.utils, actual, expected),
    };
  }

  return {
    pass: false,
    message: failMessage(this.utils, actual, expected),
  };
}
